@@ -1,5 +1,6 @@
 from snappi_trex.exceptions import SnappiTrexException
 from snappi_trex.util import Util
+from snappi_trex.info import Info
 
 class Validation(object):
     """This class contains functions to validate the input of various
@@ -16,11 +17,11 @@ class Validation(object):
         elif rate['choice'] == 'bps':
             bps = rate['bps']
         elif rate['choice'] == 'kbps':
-            bps = rate['kbps'] * 1000
+            bps = rate['kbps']
         elif rate['choice'] == 'mbps':
-            bps = rate['mbps'] * 1000000
+            bps = rate['mbps']
         elif rate['choice'] == 'gbps':
-            bps = rate['gbps'] * 1000000000
+            bps = rate['gbps']
         elif rate['choice'] == 'percentage':
             percent = rate['percentage']
         else:
@@ -68,7 +69,7 @@ class Validation(object):
 
     
     def validate_packet(packet_headers):
-        header_info = Util.get_header_info()
+        header_info = Info.get_header_info()
         for header in packet_headers:
 
             header_name = header['choice']
